Index: /applications/editors/josm/i18n/launchpad.pl
===================================================================
--- /applications/editors/josm/i18n/launchpad.pl	(revision 33158)
+++ /applications/editors/josm/i18n/launchpad.pl	(revision 33159)
@@ -9,5 +9,6 @@
 # Three ways to handle login data:
   # Enter data directly in these two lines (Be careful witn svn checkin later!)
   # create a file "launchpad.pl_credits" containing the two lines with proper values
   # leave credits empty and enter them on runtime
 $user = '';
@@ -292,4 +293,9 @@
             close FILE;
         }
+        if(open FILE, "$ENV{HOME}/.josm_i18n_launchpad.pl_credits")
+        {
+            eval <FILE>;
+            close FILE;
+        }
 
         if(!$user)
@@ -9,5 +9,6 @@
 # Three ways to handle login data:
   # Enter data directly in these two lines (Be careful witn svn checkin later!)
-  # create a file "launchpad.pl_credits" containing the two lines with proper values
+  # create a file "launchpad.pl_credits" or ~/.josm_i18n_launchpad.pl_credits
+  # containing the two lines with proper values
   # leave credits empty and enter them on runtime
 $user = '';
